@@ -9,14 +9,12 @@ makedocs(
     sitename = "CommonSolve.jl",
     authors = "Chris Rackauckas",
     modules = [CommonSolve],
-    clean = true,
-    doctest = false,
+    clean = true, doctest = false, linkcheck = true,
     format = Documenter.HTML(
-        analytics = "UA-90474609-3",
         assets = ["assets/favicon.ico"],
-        canonical = "https://docs.sciml.ai/CommonSolve/stable",
+        canonical = "https://docs.sciml.ai/CommonSolve/stable"
     ),
-    pages = pages,
+    pages = pages
 )
 
 deploydocs(repo = "github.com/SciML/CommonSolve.jl.git"; push_preview = true)
